#
# spec file for package SDL3
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sle_version 0
Name:           SDL3
%define lname   libSDL3-0
Version:        3.2.8
Release:        2.1
Summary:        Simple DirectMedia Layer Library
License:        Zlib
Group:          Development/Libraries/X11
URL:            https://libsdl.org/
#Git-Clone:     https://github.com/libsdl-org/SDL
Source:         https://github.com/libsdl-org/SDL/releases/download/release-%version/SDL3-%version.tar.gz
Source2:        https://github.com/libsdl-org/SDL/releases/download/release-%version/SDL3-%version.tar.gz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libdecor-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa) >= 1.0.11
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(ice)
# KMS/DRM driver needs libdrm and libgbm
BuildRequires:  pkgconfig(gbm) >= 11.1.0
BuildRequires:  pkgconfig(libdrm) >= 2.4.82
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.20
BuildRequires:  pkgconfig(libpulse-simple) >= 0.9
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(wayland-client) >= 1.18
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)

%description
Simple DirectMedia Layer (SDL) is a cross-platform library for
multi-media software, such as games and emulators. It provides a
generic API for access to audio, keyboard, mouse, and display
framebuffer.

%package -n %lname
Summary:        Simple DirectMedia Layer Library
Group:          System/Libraries

%description -n %lname
Simple DirectMedia Layer (SDL) is a cross-platform library for
multi-media software, such as games and emulators. It provides a
generic API for access to audio, keyboard, mouse, and display
framebuffer.

SDL uses dlopen, so if you experience problems under X11, check
again that libXrandr2 and libXi6 are in fact installed.

%package devel
Summary:        SDL3 Library Developer Files
Group:          Development/Libraries/X11
Requires:       %lname = %version-%release
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glesv1_cm)
Requires:       pkgconfig(glesv2)
Requires:       pkgconfig(glu)

%description devel
This package contains files needed for development with the SDL
library.

%package devel-doc
Summary:        Manual pages for the SDL3 API
Group:          Documentation/Man
BuildArch:      noarch

%description devel-doc
This package contains manual pages (in troff format) for the
SDL3 C API.

%prep
%autosetup -p1

%build
%global _lto_cflags %_lto_cflags -ffat-lto-objects
# SDL_*_SHARED=false -> link to libs rather than dlopen.
%cmake \
%ifarch %ix86
	-DSDL_MMX:BOOL=OFF -DSDL_SSE:BOOL=OFF -DSDL_SSE2:BOOL=OFF \
%endif
	-DSDL_SSE3:BOOL=OFF -DSDL_3DNOW:BOOL=OFF \
	-DSDL_ALSA_SHARED:BOOL=OFF -DSDL_LIBSAMPLERATE_SHARED:BOOL=OFF \
	-DSDL_PIPEWIRE_SHARED:BOOL=OFF -DSDL_PULSEAUDIO_SHARED:BOOL=OFF \
	-DSDL_X11_SHARED:BOOL=OFF -DSDL_WAYLAND_SHARED:BOOL=OFF \
	-DSDL_KMSDRM_SHARED:BOOL=OFF \
	-DSDL_STATIC:BOOL=OFF -DSDL_STATIC_PIC:BOOL=ON -DSDL_RPATH:BOOL=OFF \
	-DSDL_TEST_LIBRARY:BOOL=OFF -DSDL_INSTALL_DOCS:BOOL=ON

%cmake_build

%install
%cmake_install
rm -Rf "%buildroot/%_datadir/licenses" # we use %%license

%ldconfig_scriptlets -n %lname

%files -n %lname
%license LICENSE.txt
%_libdir/libSDL3.so.0*

%files devel
%_libdir/libSDL3.so
%_includedir/SDL3/
%_libdir/pkgconfig/sdl3.pc
%_libdir/cmake/SDL3/

%files devel-doc
%_mandir/man3/*.3*

%changelog
* Fri Mar 14 2025 Jan Engelhardt <jengelh@inai.de>
- Trim extraneous X11 dependencies from SDL3-devel [boo#1239635]
* Wed Mar  5 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.8
  * Fixed a bug restoring the desktop mode on X11
  * Fixed being unable to get message box fonts on some Linux systems
  * Fixed a potential crash unplugging a HIDAPI controller
  * Fixed the 2D clip rect when logical presentation is enabled
* Sun Mar  2 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.6
  * Added support for Motion JPEG camera capture
  * Allow 2D render targets to use logical presentation
  * Fixed audio glitch when resampling between large frequency
    differences
  * Fixed pen generated mouse events not having SDL_PEN_MOUSEID
  * Added support for the 8BitDo Micro gamepad
  * Added SDL_HINT_JOYSTICK_HAPTIC_AXES to specify how many haptic
    axes a device has
  * Fixed SDL_GetRelativeMouseState() returning no motion when not
    in relative mouse mode
  * Added SDL_PROP_SURFACE_HOTSPOT_X_NUMBER and
    SDL_PROP_SURFACE_HOTSPOT_Y_NUMBER to allow storing cursor
    hotspot positions directly in an SDL_Surface
  * Added support for high DPI icons on Wayland
  * Added color management protocol support on Wayland
  * Fixed flushing audio forever in some cases when recording
    PulseAudio on Linux
  * Fixed a rare deadlock when opening an audio device using
    PipeWire on Linux
- Delete 0001-pipewire-Ensure-that-the-correct-struct-is-used-for-.patch
  (merged)
* Tue Feb 25 2025 Jan Engelhardt <jengelh@inai.de>
- Add 0001-pipewire-Ensure-that-the-correct-struct-is-used-for-.patch
  for pipewire-1.3.x
* Fri Feb  7 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.4
  * Fixed decoding 4-bit RLE encoded BMP files
  * Fixed setting the position of X11 windows before they are shown
  * Fixed D-Pad not working when using SDL2 controller mappings
  * Fixed SDL_OpenHapticFromJoystick() not returning a valid
    haptic handle
  * Added SDL_StretchSurface() as a replacement for SDL2
    SDL_SoftStretch() and SDL_SoftStretchLinear()
  * Fixed several memory leaks
* Sun Feb  2 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.2
  * Fixed mouse motion while the mouse is grabbed on Linux
  * Fixed audio gain not applying in some cases
  * Fixed a potential crash when applying audio gain
  * Removed audio resampling frequency limit
  * Fixed a crash on Windows if a tray is created without any menus
  * Allow the window manager to position windows that do not
    specify a position on Linux
* Thu Jan 23 2025 Jan Engelhardt <jengelh@inai.de>
- Cherry pick change 6cf087f53a05 from SDL2.spec:
  Thu Aug 29 09:07:45 UTC 2024 - Antonio Larrosa <alarrosa@suse.com>
  Don't build with fcitx support. fcitx support was just added
  because of a bug (boo#1025413) that could be fixed by building
  with fcitx support but upstream SDL2 developers fixed it
  in 2.0.5 when building without fcitx support too. Also fcitx
  support has always been disabled in SLE/Leap and in Factory
  it's built against fcitx 4.2.9.9, not the newer fcitx5 so
  let's disable it in order to reduce dependencies.
* Wed Jan 22 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.2.0
  * audio: added ``SDL_AudioDeviceStreamPaused`` function
  * x11/wl: added support for Mod3 and more esoteric Xkb
    configurations
  * keyboard: added some SDL keycodes for common Xkb keys
  * Use XIM for IME input on X11
  * Added support for displaying XIM composition strings
  * Added SDL_ClickTrayEntry()
  * audio: Allow streams to change the device-side channels maps
  * Fix incorrect hotspot calculation for cursor positioning
  * Added support for the 8BitDo Ultimate 2C Wireless in
    Bluetooth mode
  * Added Linux evdev mappings for the Wireless HORIPAD For Steam
  * tray: renamed function ``SDL_HasNoActiveTrays`` to
    ``SDL_HasActiveTrays``
  * vulkan: Fixes for swapchain resize crash on X11
  * render: SDL_HINT_RENDER_DRIVER now accepts a comma-separated
    list
* Wed Jan  8 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.1.8
  * This update adds asynchronous I/O, main thread dispatching, a
    desktop tray API, debug text rendering and other features.
* Sun Dec 15 2024 Jan Engelhardt <jengelh@inai.de>
- Add baselibs.conf
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to preview release 3.1.6
  * New functions ``SDL_CalculateGPUTextureFormatSize``,
    ``SDL_CancelGPUCommandBuffer``, ``SDL_DelayPrecise``,
    ``SDL_GetSandbox``, ``SDL_RenderDebugText``,
    ``SDL_StepBackUTF8``
- Delete gcc14.patch (merged)
* Sat Oct  5 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to preview release 3.1.3
  * New GPU API for modern 3D rendering and GPU compute in a
    cross-platform manner
  * Various new cross-platform APIs around dialogs / filesystems /
    storage / camera / pen access, new example programs, audio
    streams, color-space support
  * More HiDPI support
  * Better keyboard input handling
  * Prefer PipeWire over PulseAudio
* Mon Aug 19 2024 Jan Engelhardt <jengelh@inai.de>
- Add gcc14.patch
* Wed May  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to preview release 3.1.2
  * Added SDL_GlobDirectory() and SDL_GlobStorageDirectory()
  * Reduced startup time when scanning for game controllers on
    Linux
  * Removed SDL_RENDERER_ACCELERATED, SDL_RENDERER_SOFTWARE,
    SDL_HINT_RENDER_SCALE_QUALITY, SDL_quit.h
  * Renamed SDL_eventaction to SDL_EventAction
* Thu Apr 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to preview release 3.1.1
  * Fixed a crash when rendering lots of content using the Vulkan
    renderer
  * Fixed text input being delivered when SDL_StartTextInput()
    has not been called
  * Fixed a performance regression initializing controllers on Linux
  * Separated the joystick power state into battery status and
    percentage
  * Added an optional user parameter to main callback entry points
  * Case insensitive string comparison functions are no longer
    affected by locale
* Fri Dec  2 2022 Jan Engelhardt <jengelh@inai.de>
- Initial package (3.0~git251.1a890808a) for build.opensuse.org
